@@ -4,21 +4,32 @@ This function allows you to query your Wallet balance. If you enable notify by e
 URL :
 https://greydotapi.me/?k=[APP Key]&do=[FID]
 
-[APP Key] Your APP Key
-[FID]The function ID for Wallet balanc is 3
+[**APP Key**] Your APP Key
+
+[**FID**]The function ID for Wallet balance is 2
+
 
 Example url :
-https://greydotapi.me/?k=abcdefghijklmnopqrst&do=3
+https://greydotapi.me/?k=abcdefghijklmnopqrst&do=2
 
 Example reply :
-<?xml version="1.0" encoding="utf-8" ?>
-<query>
+
+    <?xml version="1.0" encoding="utf-8" ?>
+
+    <query>
+
     <query_result>
-        <status>Success</status>
-        <function>Digit balance</function>
-        <amount>10.00</amount>
+
+    <status>Success</status>
+
+    <function>Digit balance</function>
+
+    <amount>10.00</amount>
+
     </query_result>
+
     <query_status>DONE</query_status>
+
     <query_code>D0003</query_code>
-</query>
+
 """
